# isqtools

```{toctree}
:hidden:

Home<self>
Getting Started<get_started>
Tutorials<tutorials/index>
API<apidocs>
```

```{include} ../../README.md
:start-after: <!-- home start -->
:end-before: <!-- home end -->
```

Click [here](get_started) to get started.
